@@ -4,7 +4,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.util.Arrays;
 import java.util.logging.Level;
-import uk.ac.starlink.fits.FitsConstants;
 import uk.ac.starlink.table.StarTableFactory;
 import uk.ac.starlink.table.TableScheme;
 import uk.ac.starlink.task.Task;
@@ -51,7 +50,6 @@ public class Stilts {
         int status = invoker.invoke( args, new Runnable() {
             public void run() {
                 URLUtils.installCustomHandlers();
-                FitsConstants.configureHierarch();
                 PropertyAuthenticator.installInstance( true );
             }
         } );
@@ -185,6 +183,7 @@ public class Stilts {
         taskFactory_.register( "tskymatch2", taskPkg + "SkyMatch2" );
         taskFactory_.register( "votcopy", taskPkg + "VotCopy" );
         taskFactory_.register( "votlint", taskPkg + "VotLint" );
+        taskFactory_.register( "xsdvalidate", taskPkg + "XsdValidate" );
 
         /* Add entries for plot2 tasks to both the generic factory and
          * the plot2-specific one. */
